@@ -21,7 +21,6 @@ import uuid
 
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
-from oslo_utils import importutils
 import prettytable
 import six
 from six.moves.urllib import error
@@ -30,7 +29,6 @@ from six.moves.urllib import request
 import yaml
 
 from heatclient._i18n import _
-from heatclient._i18n import _LE
 from heatclient import exc
 
 LOG = logging.getLogger(__name__)
@@ -208,6 +206,8 @@ class EventLogContext(object):
         # future calls to build_resource_name
 
         def get_stack_id():
+            if getattr(event, 'stack_id', None) is not None:
+                return event.stack_id
             for l in getattr(event, 'links', []):
                 if l.get('rel') == 'stack':
                     if 'href' not in l:
@@ -218,8 +218,8 @@ class EventLogContext(object):
         stack_id = get_stack_id()
         if not stack_id:
             return res_name
-        phys_id = getattr(event, 'physical_resource_id')
-        status = getattr(event, 'resource_status')
+        phys_id = getattr(event, 'physical_resource_id', None)
+        status = getattr(event, 'resource_status', None)
 
         is_stack_event = stack_id == phys_id
         if is_stack_event:
@@ -322,13 +322,6 @@ def find_resource(manager, name_or_id):
         raise exc.CommandError(msg)
 
 
-def import_versioned_module(version, submodule=None):
-    module = 'heatclient.v%s' % version
-    if submodule:
-        module = '.'.join((module, submodule))
-    return importutils.import_module(module)
-
-
 def format_parameters(params, parse_semicolon=True):
     '''Reformat parameters into dict of format expected by the API.'''
 
@@ -383,7 +376,7 @@ def format_parameter_file(param_files, template_file=None,
             template_file, template_url))
 
     param_file = {}
-    for key, value in six.iteritems(params):
+    for key, value in params.items():
                 param_file[key] = resolve_param_get_file(value,
                                                          template_base_url)
     return param_file
@@ -450,7 +443,7 @@ def get_response_body(resp):
         try:
             body = resp.json()
         except ValueError:
-            LOG.error(_LE('Could not decode response body as JSON'))
+            LOG.error('Could not decode response body as JSON')
     else:
         body = None
     return body
