@@ -13,8 +13,9 @@
 import sys
 
 from oslo_serialization import jsonutils
+from oslo_utils import reflection
 
-from heatclient.openstack.common._i18n import _
+from heatclient._i18n import _
 
 verbose = 0
 
@@ -44,7 +45,7 @@ class HTTPException(BaseException):
     """Base exception for all HTTP-derived exceptions."""
     code = 'N/A'
 
-    def __init__(self, message=None):
+    def __init__(self, message=None, code=None):
         super(HTTPException, self).__init__(message)
         try:
             self.error = jsonutils.loads(message)
@@ -59,6 +60,8 @@ class HTTPException(BaseException):
         except Exception:
             self.error = {'error':
                           {'message': self.message or self.__class__.__doc__}}
+        if self.code == "N/A" and code is not None:
+            self.code = code
 
     def __str__(self):
         message = self.error['error'].get('message', 'Internal Error')
@@ -78,9 +81,9 @@ class HTTPMultipleChoices(HTTPException):
                          "available.")
         return (_("%(name)s (HTTP %(code)s) %(details)s") %
                 {
-                    'name': self.__class__.__name__,
-                    'code': self.code,
-                    'details': self.details})
+                'name': reflection.get_class_name(self, fully_qualified=False),
+                'code': self.code,
+                'details': self.details})
 
 
 class BadRequest(HTTPException):
@@ -119,6 +122,10 @@ class HTTPNotFound(NotFound):
     pass
 
 
+class NoUniqueMatch(HTTPException):
+    pass
+
+
 class HTTPMethodNotAllowed(HTTPException):
     code = 405
 
@@ -178,7 +185,7 @@ for obj_name in dir(sys.modules[__name__]):
 def from_response(response):
     """Return an instance of an HTTPException based on requests response."""
     cls = _code_map.get(response.status_code, HTTPException)
-    return cls(response.content)
+    return cls(response.content, response.status_code)
 
 
 class NoTokenLookupException(Exception):
