@@ -282,6 +282,11 @@ class UpdateStack(command.ShowOne):
             help=_('Wait until stack goes to UPDATE_COMPLETE or '
                    'UPDATE_FAILED')
         )
+        parser.add_argument(
+            '--converge',
+            action='store_true',
+            help=_('Stack update with observe on reality.')
+        )
 
         return parser
 
@@ -361,6 +366,9 @@ class UpdateStack(command.ShowOne):
                                             limit=1)
             marker = events[0].id if events else None
 
+        if parsed_args.converge:
+            fields['converge'] = True
+
         client.stacks.update(**fields)
 
         if parsed_args.wait:
@@ -1001,11 +1009,6 @@ class OutputShowStack(command.ShowOne):
             msg = _('Output error: %s') % output['output_error']
             raise exc.CommandError(msg)
 
-        if (isinstance(output['output_value'], list) or
-                isinstance(output['output_value'], dict)):
-            output['output_value'] = heat_utils.json_formatter(
-                output['output_value'])
-
         return self.dict2columns(output)
 
 
@@ -1215,16 +1218,23 @@ class CancelStack(StackActionBase):
 
     Supported tasks for cancellation:
     * update
+    * create
     """
 
     log = logging.getLogger(__name__ + '.CancelStack')
 
     def get_parser(self, prog_name):
-        return self._get_parser(
+        parser = self._get_parser(
             prog_name,
             _('Stack(s) to cancel (name or ID)'),
-            _('Wait for check to complete')
+            _('Wait for cancel to complete')
         )
+        parser.add_argument(
+            '--no-rollback',
+            action='store_true',
+            help=_('Cancel without rollback')
+        )
+        return parser
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)", parsed_args)
@@ -1237,20 +1247,25 @@ class CancelStack(StackActionBase):
             'Updated Time'
         ]
         heat_client = self.app.client_manager.orchestration
-
+        if parsed_args.no_rollback:
+            action = heat_client.actions.cancel_without_rollback
+            allowed_statuses = ['create_in_progress',
+                                'update_in_progress']
+        else:
+            action = heat_client.actions.cancel_update
+            allowed_statuses = ['update_in_progress']
         for stack in parsed_args.stack:
             try:
                 data = heat_client.stacks.get(stack_id=stack)
             except heat_exc.HTTPNotFound:
                 raise exc.CommandError('Stack not found: %s' % stack)
-
             status = getattr(data, 'stack_status').lower()
-            if status == 'update_in_progress':
+            if status in allowed_statuses:
                 data = _stack_action(
                     stack,
                     parsed_args,
                     heat_client,
-                    heat_client.actions.cancel_update
+                    action
                 )
                 rows += [utils.get_dict_properties(data.to_dict(), columns)]
             else:
