@@ -15,7 +15,6 @@
 
 import collections
 from oslo_utils import encodeutils
-import six
 from six.moves.urllib import parse
 
 from heatclient.common import base
@@ -54,7 +53,7 @@ class EventManager(stacks.StackChildManager):
             filters = kwargs.pop('filters')
             params.update(filters)
 
-        for key, value in six.iteritems(kwargs):
+        for key, value in kwargs.items():
             if value:
                 params[key] = value
 
